@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * gccv/canvas.cc 
+ * gccv/canvas.cc
  *
- * Copyright (C) 2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2008-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -60,7 +60,8 @@ static GtkWidget *gccv_canvas_new (gccv::Canvas *owner)
 						   GDK_POINTER_MOTION_MASK |
 						   GDK_BUTTON_MOTION_MASK |
 						   GDK_BUTTON_PRESS_MASK |
-						   GDK_BUTTON_RELEASE_MASK
+						   GDK_BUTTON_RELEASE_MASK |
+    					   GDK_LEAVE_NOTIFY_MASK
 						   );
 	return w;
 }
@@ -74,24 +75,35 @@ public:
 	static bool OnButtonPressed (Canvas *canvas, GdkEventButton *event);
 	static bool OnButtonReleased (Canvas *canvas, GdkEventButton *event);
 	static bool OnMotion (Canvas *canvas, GdkEventMotion *event);
-	static bool OnExpose (Canvas *canvas, GdkEventExpose *event);
+	static bool OnDraw (Canvas *canvas, cairo_t *cr);
+	static bool OnLeaveNotify (Canvas *canvas, GdkEventCrossing *event);
 };
 
 
-bool CanvasPrivate::OnExpose (Canvas *canvas, GdkEventExpose *event)
+bool CanvasPrivate::OnDraw (Canvas *canvas, cairo_t *cr)
 {
 	double x0, y0, x1, y1;
+	GdkEvent *ev = gtk_get_current_event ();
 	canvas->m_Root->GetBounds (x0, y0, x1, y1);
-	x0 *= canvas->m_Zoom;
-	x1 *= canvas->m_Zoom;
-	y0 *= canvas->m_Zoom;
-	y1 *= canvas->m_Zoom;
-	if (x0 <= event->area.x + event->area.width && x1 >= event->area.x && y0 <= event->area.y + event->area.height && y1 >= event->area.y) {
-		cairo_t *cr = gdk_cairo_create (gtk_widget_get_window (canvas->m_Widget));
-		cairo_scale (cr, canvas->m_Zoom, canvas->m_Zoom);
-		canvas->m_Root->Draw (cr, event->area.x / canvas->m_Zoom, event->area.y / canvas->m_Zoom, (event->area.x + event->area.width) / canvas->m_Zoom, (event->area.y + event->area.height) / canvas->m_Zoom, false);
-		cairo_destroy (cr);
-	}
+	cairo_save (cr);
+	cairo_scale (cr, canvas->m_Zoom, canvas->m_Zoom);
+	// get the default color
+	GtkStateFlags state = gtk_widget_get_state_flags (canvas->m_Widget);
+	GtkStyleContext *ctxt = gtk_widget_get_style_context (canvas->m_Widget);
+	GdkRGBA rgba;
+	gtk_style_context_get_color (ctxt, state, &rgba);
+	canvas->m_Color = GO_COLOR_FROM_GDK_RGBA (rgba);
+	if (ev && ev->type == GDK_EXPOSE) {
+		GdkEventExpose *event = reinterpret_cast < GdkEventExpose * > (ev);
+		x0 *= canvas->m_Zoom;
+		x1 *= canvas->m_Zoom;
+		y0 *= canvas->m_Zoom;
+		y1 *= canvas->m_Zoom;
+		if (x0 <= event->area.x + event->area.width && x1 >= event->area.x && y0 <= event->area.y + event->area.height && y1 >= event->area.y)
+			canvas->m_Root->Draw (cr, event->area.x / canvas->m_Zoom, event->area.y / canvas->m_Zoom, (event->area.x + event->area.width) / canvas->m_Zoom, (event->area.y + event->area.height) / canvas->m_Zoom, false);
+	} else
+		canvas->m_Root->Draw (cr, x0, y0, x1, y1, true);
+	cairo_restore (cr);
 	return true;
 }
 
@@ -132,6 +144,12 @@ bool CanvasPrivate::OnMotion (Canvas *canvas, GdkEventMotion *event)
 	return (canvas->m_Client)? (canvas->m_Dragging? canvas->m_Client->OnDrag (client, x, y, event->state): canvas->m_Client->OnMotion (client, x, y, event->state)): true;
 }
 
+bool CanvasPrivate::OnLeaveNotify (Canvas *canvas, GdkEventCrossing *event)
+{
+	canvas->m_LastEventState = event->state;
+	return (canvas->m_Client)? canvas->m_Client->OnLeaveNotify (event->state): true;
+}
+
 static void on_destroy (Canvas *canvas)
 {
 	delete canvas;
@@ -142,15 +160,17 @@ Canvas::Canvas (Client *client):
 	m_Dragging (false),
 	m_Zoom (1.),
 	m_Root (NULL),
-	m_Gap (0.)
+	m_Gap (0.),
+	m_BackgroundColor (0)
 {
 	m_Root = new Group (this);
 	m_Widget = GTK_WIDGET (gccv_canvas_new (this));
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "button-press-event", G_CALLBACK (CanvasPrivate::OnButtonPressed), this);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "button-release-event", G_CALLBACK (CanvasPrivate::OnButtonReleased), this);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "motion-notify-event", G_CALLBACK (CanvasPrivate::OnMotion), this);
+	g_signal_connect_swapped (G_OBJECT (m_Widget), "leave-notify-event", G_CALLBACK (CanvasPrivate::OnLeaveNotify), this);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "destroy", G_CALLBACK (on_destroy), this);
-	g_signal_connect_swapped (G_OBJECT (m_Widget), "expose-event", G_CALLBACK (CanvasPrivate::OnExpose), this);
+	g_signal_connect_swapped (G_OBJECT (m_Widget), "draw", G_CALLBACK (CanvasPrivate::OnDraw), this);
 }
 
 Canvas::~Canvas()
@@ -177,15 +197,15 @@ void Canvas::Invalidate (double x0, double y0, double x1, double y1)
 		if (y1 < 0.)
 			y1 = 0.;
 	}
-	gtk_widget_queue_draw_area (m_Widget, (int) floor (x0 * m_Zoom), (int) floor (y0 * m_Zoom), (int) ceil (x1 * m_Zoom), (int) ceil (y1 * m_Zoom));
+	gtk_widget_queue_draw_area (m_Widget, (int) floor (x0 * m_Zoom), (int) floor (y0 * m_Zoom), (int) (ceil (x1 * m_Zoom) - floor (x0 * m_Zoom)), (int) (ceil (y1 * m_Zoom) - floor (y0 * m_Zoom)));
 }
 
 void Canvas::SetBackgroundColor (GOColor color)
 {
 	m_BackgroundColor = color;
-	GdkColor gcolor;
-	go_color_to_gdk (color, &gcolor);
-	gtk_widget_modify_bg (m_Widget, GTK_STATE_NORMAL, &gcolor);
+	GdkRGBA rgba;
+	go_color_to_gdk_rgba (color, &rgba);
+	gtk_widget_override_background_color (m_Widget, GTK_STATE_FLAG_NORMAL, &rgba);
 }
 
 void Canvas::SetZoom (double zoom)
