@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * arrow.h 
+ * arrow.h
  *
  * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -101,7 +101,16 @@ Sets the position and length of an arrow.
 
 Retrieves the position of the arrow.
 */
-	bool GetCoords (double* xstart, double* ystart, double* xend, double* yend);
+	bool GetCoords (double* xstart, double* ystart, double* xend, double* yend) const;
+/*!
+@param x a pointer to the double value which will receive the x coordinate of the Arrow.
+@param y a pointer to the double value which will receive the y coordinate of the Arrow.
+@param z a pointer to the double value which will receive the z coordinate of the Arrow or NULL for 2D representations.
+
+Retrieves the coordinates of this Arrow.
+@return true if successful and false if an error occurs (if x or y is NULL).
+*/
+	bool GetCoords (double *x, double *y, double *z = NULL) const;
 /*!
 @param x: the x component of the transation vector.
 @param y: the y component of the transation vector.
@@ -119,7 +128,7 @@ Used to move and/or transform an arrow.
 */
 	void Transform2D (gcu::Matrix2D& m, double x, double y);
 /*!
-Used to retrieve the y coordinate for alignment. 
+Used to retrieve the y coordinate for alignment.
 @return y coordinate used for arrows alignment.
 */
 	double GetYAlign ();
