@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * bond.cc 
+ * bond.cc
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -40,6 +40,7 @@
 #include <gccv/wedge.h>
 #include <gcu/cycle.h>
 #include <gcu/objprops.h>
+#include <gcugtk/ui-manager.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <cstring>
@@ -225,7 +226,7 @@ general:
 								a = tan ((bond->GetAngle2DRad (static_cast <Atom*> (m_End)) - a0) / 2);
 								if (sign * a < sign * tanb)
 									tanb = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_End->GetNextBond (it));
 						}
@@ -253,7 +254,7 @@ general:
 									a = tan ((bond->GetAngle2DRad (static_cast <Atom*> (m_Begin)) - a2) / 2);
 									if (sign * a < sign * tanb)
 										tanb = a;
-									
+
 								}
 								bond = static_cast <Bond*> (m_Begin->GetNextBond (it));
 							}
@@ -279,7 +280,7 @@ general:
 									tana = a;
 								if (a < tanb)
 									tanb = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_Begin->GetNextBond (it));
 						}
@@ -293,7 +294,7 @@ general:
 									tanc = a;
 								if (a < tand)
 									tand = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_End->GetNextBond (it));
 						}
@@ -524,7 +525,7 @@ void Bond::SetSelected (int state)
 	if (!m_order || !m_Item)
 		return;
 	GOColor color;
-	switch (state) {	
+	switch (state) {
 	case SelStateUnselected:
 		color = Color;
 		break;
@@ -685,7 +686,7 @@ void Bond::UpdateItem ()
 	}
 	AddItem ();
 }
-	
+
 double Bond::GetYAlign ()
 {
 	double x1, y1, x2, y2;
@@ -753,13 +754,14 @@ static void on_move_to_back (Bond *pBond)
 	pBond->MoveToBack ();
 }
 
-bool Bond::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
+bool Bond::BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y)
 {
 	Object *pAtom = GetAtomAt (x, y);
 	if (pAtom)
 		return pAtom->BuildContextualMenu (UIManager, object, x, y);
 	if (m_Crossing.size () == 0)
 		return Object::BuildContextualMenu (UIManager, object, x, y);
+	GtkUIManager *uim = static_cast < gcugtk::UIManager * > (UIManager)->GetUIManager ();
 	bool is_before = false, is_after = false;
 	if (m_Crossing.size () > 0) {
 		map<Bond*, BondCrossing>::iterator i, iend = m_Crossing.end ();
@@ -784,16 +786,16 @@ bool Bond::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (on_move_to_back), this);
 		gtk_action_group_add_action (group, action);
 		g_object_unref (action);
-		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Bond'><menuitem action='MoveBack'/></menu></popup></ui>", -1, NULL);
+		gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Bond'><menuitem action='MoveBack'/></menu></popup></ui>", -1, NULL);
 	}
 	if (is_after) {
 		action = gtk_action_new ("BringFront", _("Bring to front"), NULL, NULL);
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (on_bring_to_front), this);
 		gtk_action_group_add_action (group, action);
 		g_object_unref (action);
-		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Bond'><menuitem action='BringFront'/></menu></popup></ui>", -1, NULL);
+		gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Bond'><menuitem action='BringFront'/></menu></popup></ui>", -1, NULL);
 	}
-	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	gtk_ui_manager_insert_action_group (uim, group, 0);
 	g_object_unref (group);
 	Object::BuildContextualMenu (UIManager, object, x, y);
 	return true;
