@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * mesomery-arrow.cc 
+ * mesomery-arrow.cc
  *
- * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -33,6 +33,7 @@
 #include "widgetdata.h"
 #include <gccv/arrow.h>
 #include <gccv/canvas.h>
+#include <glib/gi18n-lib.h>
 
 using namespace gcu;
 
@@ -111,6 +112,7 @@ bool MesomeryArrow::Load (xmlNodePtr node)
 		}
 		if (m_Start)
 			m_Start->AddArrow (this, m_End);
+		GetDocument ()->ObjectLoaded (this);
 		return true;
 	}
 	return false;
@@ -158,4 +160,9 @@ void MesomeryArrow::Reverse ()
 	m_height = - m_height;
 }
 
+std::string MesomeryArrow::Name ()
+{
+	return _("Mesomery arrow");
+}
+
 }	//	namespace gcp
