@@ -28,9 +28,9 @@
 #include "bond.h"
 #include "document.h"
 #include "molecule.h"
-#include "stringdlg.h"
 #include "tool.h"
 #include "view.h"
+#include <gcugtk/stringdlg.h>
 #include <gcugtk/ui-manager.h>
 #include <gcu/chain.h>
 #include <gsf/gsf-input-memory.h>
@@ -49,12 +49,6 @@ using namespace std;
 
 namespace gcp {
 
-typedef struct {
-	std::string name;
-	std::string uri;
-	std::string classname;
-} BaseAccess;
-
 class MoleculePrivate
 {
 public:
@@ -65,30 +59,24 @@ public:
 	static void ExportTo3D (Molecule *mol);
 	static void ExportToAvogadro (Molecule *mol);
 	static char *Build3D (Molecule *mol);
-	static void LoadDatabases (char const *filename);
-	static void ShowDatabase (GObject *action);
-
-	static std::vector < BaseAccess > Databases;
 };
 
-std::vector < BaseAccess > MoleculePrivate::Databases;
-
 void MoleculePrivate::ShowInChIKey (Molecule *mol)
 {
 
-	new StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetInChIKey (), StringDlg::INCHIKEY);
+	new gcugtk::StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetInChIKey (), gcugtk::StringDlg::INCHIKEY);
 }
 
 void MoleculePrivate::ShowInChI (Molecule *mol)
 {
 
-	new StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetInChI (), StringDlg::INCHI);
+	new gcugtk::StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetInChI (), gcugtk::StringDlg::INCHI);
 }
 
 void MoleculePrivate::ShowSMILES (Molecule *mol)
 {
 
-	new StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetSMILES (), StringDlg::SMILES);
+	new gcugtk::StringDlg (reinterpret_cast<Document *>(mol->GetDocument ()), mol->GetSMILES (), gcugtk::StringDlg::SMILES);
 }
 
 char *MoleculePrivate::Build3D (Molecule *mol)
@@ -150,97 +138,6 @@ void MoleculePrivate::ExportToAvogadro (Molecule *mol)
 	g_free (command_line);
 }
 
-static void
-database_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
-{
-	BaseAccess *state = static_cast < BaseAccess * > (xin->user_state);
-	if (state->classname == "molecule" && state->name.length () && state->uri.length ())
-		MoleculePrivate::Databases.push_back (*state);
-	state->name.clear ();
-	state->uri.clear ();
-	state->classname.clear ();
-};
-
-static void
-database_name_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
-{
-	BaseAccess *state = static_cast < BaseAccess * > (xin->user_state);
-	state->name = _(xin->content->str); // this one might be translated
-};
-
-static void
-database_uri_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
-{
-	BaseAccess *state = static_cast < BaseAccess * > (xin->user_state);
-	state->uri = xin->content->str;
-};
-
-static void
-database_class_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
-{
-	BaseAccess *state = static_cast < BaseAccess * > (xin->user_state);
-	state->classname = xin->content->str;
-};
-
-static GsfXMLInNode const databases_dtd[] = {
-GSF_XML_IN_NODE (DATABASES, DATABASES, -1, "databases", GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (DATABASES, DATABASE, -1, "database", GSF_XML_NO_CONTENT, NULL, database_end),
-		GSF_XML_IN_NODE (DATABASE, NAME, -1, "name", GSF_XML_CONTENT, NULL, database_name_end),
-		GSF_XML_IN_NODE (DATABASE, URI, -1, "uri", GSF_XML_CONTENT, NULL, database_uri_end),
-		GSF_XML_IN_NODE (DATABASE, CLASS, -1, "class", GSF_XML_CONTENT, NULL, database_class_end),
-	GSF_XML_IN_NODE_END
-};
-
-void MoleculePrivate::LoadDatabases (char const *filename)
-{
-	GError *err = NULL;
-	GsfInput *input = gsf_input_stdio_new (filename, &err);
-	if (err) {
-		g_error_free (err);
-		return;
-	}
-	GsfXMLInDoc *xml = gsf_xml_in_doc_new (databases_dtd, NULL);
-	BaseAccess state;
-	gsf_xml_in_doc_parse (xml, input, &state);
-
-	gsf_xml_in_doc_free (xml);
-	g_object_unref (input);
-}
-
-typedef struct {
-	Molecule *mol;
-	BaseAccess *access;
-} AccessState;
-
-void MoleculePrivate::ShowDatabase (GObject *action)
-{
-	AccessState *state = static_cast < AccessState * > (g_object_get_data (action, "state"));
-	if (state) {
-		std::string uri = state->access->uri;
-		size_t pos = uri.find ('%');
-		std::string key;
-		switch (uri[pos + 1]) {
-		case 'I':
-			key = state->mol->GetInChI ();
-			break;
-		case 'K':
-			key = state->mol->GetInChIKey ();
-			break;
-		case 'S':
-			key = state->mol->GetSMILES ();
-			break;
-		default:
-			return;
-		}
-		if (key.length () == 0)
-			return;
-		char *escaped = g_uri_escape_string (key.c_str (), NULL, false);
-		uri.replace (pos, 2, escaped);
-		g_free (escaped);
-		static_cast < Document * > (state->mol->GetDocument ())->GetApplication ()->ShowURI (uri);
-	}
-}
-
 static void do_select_alignment (GObject *action, Molecule* pMol)
 {
 	Object *object = (Object*) g_object_get_data (action, "item");
@@ -252,13 +149,13 @@ static void do_open_in_calc (Molecule* pMol)
 	pMol->OpenCalc ();
 }
 
-Molecule::Molecule (TypeId Type): gcu::Molecule (Type, gcu::ContentType2D)
+Molecule::Molecule (TypeId Type): gcugtk::Molecule (Type, gcu::ContentType2D)
 {
 	m_Alignment = NULL;
 	m_IsResidue = false;
 }
 
-Molecule::Molecule (Atom* pAtom): gcu::Molecule (pAtom, gcu::ContentType2D)
+Molecule::Molecule (Atom* pAtom): gcugtk::Molecule (pAtom, gcu::ContentType2D)
 {
 	m_Alignment = NULL;
 	m_IsResidue = false;
@@ -708,48 +605,17 @@ bool Molecule::BuildContextualMenu (gcu::UIManager *UIManager, Object *object, d
 				gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Molecule'><menu action='open3d'><menuitem action='avogadro'/></menu></menu></popup></ui>", -1, NULL);
 			}
 		}
-		// add databases submenu
-		if (MoleculePrivate::Databases.empty ()) {
-			// load them using gsf xml support
-			// first $DATADIR/gchemutils/API_VER/databases.xml
-			MoleculePrivate::LoadDatabases (DATADIR"/gchemutils/"GCU_API_VER"/databases.xml");
-			// and now $HOME/.gchemutils/datatases.xml
-			std::string home = getenv ("HOME");
-			home += "/.gchemutils/databases.xml";
-			MoleculePrivate::LoadDatabases (home.c_str ());
-		}
-		if (!MoleculePrivate::Databases.empty ()) {
-			action = gtk_action_new ("database", _("Find in databases"), NULL, NULL);
-			gtk_action_group_add_action (group, action);
-			g_object_unref (action);
-			std::vector < BaseAccess >::iterator it, end = MoleculePrivate::Databases.end ();
-			for (it = MoleculePrivate::Databases.begin (); it != end; it++) {
-				AccessState *state = g_new0 (AccessState, 1);
-				state->access = &(*it);
-				state->mol = this;
-				action = gtk_action_new ((*it).name.c_str (), (*it).name.c_str (), NULL, NULL);
-				g_object_set_data_full (G_OBJECT (action), "state", state, g_free);
-				g_signal_connect (action, "activate", G_CALLBACK (MoleculePrivate::ShowDatabase), NULL);
-				gtk_action_group_add_action (group, action);
-				g_object_unref (action);
-				std::string node = "<ui><popup><menu action='Molecule'><menu action='database'><menuitem action='";
-				node += (*it).name;
-				node += "'/></menu></menu></popup></ui>";
-				gtk_ui_manager_add_ui_from_string (uim, node.c_str (), -1, NULL);
-			}
-		}
-		//		if (((Document*) GetDocument ())->GetApplication ()->HaveInChI ()) {
-			action = gtk_action_new ("inchi", _("Generate InChI"), NULL, NULL);
-			g_signal_connect_swapped (action, "activate", G_CALLBACK (MoleculePrivate::ShowInChI), this);
-			gtk_action_group_add_action (group, action);
-			g_object_unref (action);
-			gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Molecule'><menuitem action='inchi'/></menu></popup></ui>", -1, NULL);
-			action = gtk_action_new ("inchikey", _("Generate InChIKey"), NULL, NULL);
-			g_signal_connect_swapped (action, "activate", G_CALLBACK (MoleculePrivate::ShowInChIKey), this);
-			gtk_action_group_add_action (group, action);
-			g_object_unref (action);
-			gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Molecule'><menuitem action='inchikey'/></menu></popup></ui>", -1, NULL);
-//		}
+		BuildDatabasesMenu (uim, "<ui><popup><menu action='Molecule'>", "</menu></popup></ui>");
+		action = gtk_action_new ("inchi", _("Generate InChI"), NULL, NULL);
+		g_signal_connect_swapped (action, "activate", G_CALLBACK (MoleculePrivate::ShowInChI), this);
+		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
+		gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Molecule'><menuitem action='inchi'/></menu></popup></ui>", -1, NULL);
+		action = gtk_action_new ("inchikey", _("Generate InChIKey"), NULL, NULL);
+		g_signal_connect_swapped (action, "activate", G_CALLBACK (MoleculePrivate::ShowInChIKey), this);
+		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
+		gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menu action='Molecule'><menuitem action='inchikey'/></menu></popup></ui>", -1, NULL);
 		action = gtk_action_new ("smiles", _("Generate SMILES"), NULL, NULL);
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (MoleculePrivate::ShowSMILES), this);
 		gtk_action_group_add_action (group, action);
