@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * preferences.cc 
+ * preferences.cc
  *
- * Copyright (C) 2006-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -68,8 +68,16 @@ public:
 	static void OnThemeNameChanged (PrefsDlg *dlg, char const *name) {dlg->OnThemeNameChanged (name);}
 	static bool CheckError (PrefsDlg *dlg) {return dlg->CheckError ();}
 	static void SetDefaultTheme (PrefsDlg *dlg, char const *name) {dlg->SetDefaultTheme (name);}
+	static void OnUseAtomColors (GtkToggleButton *btn, Application *app);
 };
 
+void PrefsDlgPrivate::OnUseAtomColors (GtkToggleButton *btn, Application *app)
+{
+	GOConfNode *node = go_conf_get_node (app->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	go_conf_set_bool (node, "use-atom-colors", gtk_toggle_button_get_active (btn));
+	go_conf_free_node (node);
+}
+
 static int get_fontstyle (PangoStyle val)
 {
 	switch (val) {
@@ -90,12 +98,10 @@ static int get_fontweight (PangoWeight val)
 		case PANGO_WEIGHT_BOLD: return 7;
 		case PANGO_WEIGHT_ULTRABOLD: return 8;
 		case PANGO_WEIGHT_HEAVY: return 9;
-#if PANGO_VERSION_MAJOR > 1 || PANGO_VERSION_MINOR >= 24
 		case PANGO_WEIGHT_THIN: return 1;
 		case PANGO_WEIGHT_BOOK: return 38;
 		case PANGO_WEIGHT_MEDIUM: return 5;
 		case PANGO_WEIGHT_ULTRAHEAVY: return 10;
-#endif
 		default: return 4;
 	}
 }
@@ -285,13 +291,13 @@ static bool on_delete_event (GtkWidget* widget, G_GNUC_UNUSED GdkEvent *event, P
 	return res;
 }
 
-static void on_default_theme_changed (GtkComboBox *box, PrefsDlg* dlg)
+static void on_default_theme_changed (GtkComboBoxText *box, PrefsDlg* dlg)
 {
-	PrefsDlgPrivate::SetDefaultTheme (dlg, gtk_combo_box_get_active_text (box));
+	PrefsDlgPrivate::SetDefaultTheme (dlg, gtk_combo_box_text_get_active_text (box));
 }
 
 PrefsDlg::PrefsDlg (Application *pApp):
-	Dialog (pApp, UIDIR"/preferences.ui", "preferences", GETTEXT_PACKAGE, pApp),
+	gcugtk::Dialog (pApp, UIDIR"/preferences.ui", "preferences", GETTEXT_PACKAGE, pApp),
 	Object (),
 	m_CurTheme (NULL),
 	m_Path (NULL)
@@ -305,6 +311,9 @@ PrefsDlg::PrefsDlg (Application *pApp):
 	w = GetWidget ("invert-wedge-hashes");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), InvertWedgeHashes);
 	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_invert_wedge_hashes_changed), pApp);
+	w = GetWidget ("use-atom-colors");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), pApp->GetUseAtomColors ());
+	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (PrefsDlgPrivate::OnUseAtomColors), pApp);
 	// retrieve theme widgets and set signals
 	m_BondLengthBtn = GTK_SPIN_BUTTON (GetWidget ("bond-length-btn"));
 	g_signal_connect (G_OBJECT (m_BondLengthBtn), "value-changed", G_CALLBACK (on_bond_length_changed), this);
@@ -322,13 +331,15 @@ PrefsDlg::PrefsDlg (Application *pApp):
 	g_signal_connect (G_OBJECT (m_HashDistBtn), "value-changed", G_CALLBACK (on_hash_dist_changed), this);
 	// add font selector
 	m_FontSel = GCP_FONT_SEL (g_object_new (GCP_TYPE_FONT_SEL, NULL));
-	w = GetWidget ("atom-font-box");
-	gtk_box_pack_start (GTK_BOX (w), GTK_WIDGET (m_FontSel), true, true, 0);
+	w = GetWidget ("atom-font-grid");
+	gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (m_FontSel));
+	g_object_set (m_FontSel, "expand", true, NULL);
 	m_FontChanged = g_signal_connect (G_OBJECT (m_FontSel), "changed", G_CALLBACK (on_font_changed), this);
 	// add text font selector
 	m_TextFontSel = GCP_FONT_SEL (g_object_new (GCP_TYPE_FONT_SEL, NULL));
-	w = GetWidget ("text-box");
-	gtk_box_pack_start (GTK_BOX (w), GTK_WIDGET (m_TextFontSel), true, true, 0);
+	w = GetWidget ("text-grid");
+	gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (m_TextFontSel));
+	g_object_set (m_TextFontSel, "expand", true, NULL);
 	m_TextFontChanged = g_signal_connect (G_OBJECT (m_TextFontSel), "changed", G_CALLBACK (on_text_font_changed), this);
 	// arrow spin buttons
 	m_ArrowLengthBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-length-btn"));
@@ -379,16 +390,14 @@ PrefsDlg::PrefsDlg (Application *pApp):
 	if (default_name == "Default")
 			default_name = _("Default");
 	Theme *theme, *default_theme = TheThemeManager.GetDefaultTheme ();
-	m_DefaultThemeBox = GTK_COMBO_BOX (gtk_combo_box_new_text ());
-	gtk_table_attach (GTK_TABLE (GetWidget ("table1")), GTK_WIDGET (m_DefaultThemeBox), 1, 3, 2, 3,
-													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+	m_DefaultThemeBox = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
+	gtk_grid_attach (GTK_GRID (GetWidget ("prefs-grid")), GTK_WIDGET (m_DefaultThemeBox), 1, 3, 2, 1);
 	int n = 0;
 	for (i = theme_names.begin (); i != iend; i++) {
 		theme = TheThemeManager.GetTheme (*i);
-		gtk_combo_box_append_text (m_DefaultThemeBox, (*i).c_str ());
+		gtk_combo_box_text_append_text (m_DefaultThemeBox, (*i).c_str ());
 		if (theme == default_theme)
-			gtk_combo_box_set_active (m_DefaultThemeBox, n);
+			gtk_combo_box_set_active (GTK_COMBO_BOX (m_DefaultThemeBox), n);
 		n++;
 		if (theme)
 			theme->AddClient (this);
@@ -436,7 +445,7 @@ PrefsDlg::PrefsDlg (Application *pApp):
 		gtk_tree_selection_select_path (m_ThemesSelection, m_Path);
 		gtk_tree_view_scroll_to_cell (m_ThemesView, m_Path, column, FALSE, 0., 0.);
 	}
-	
+
 	// add event handler to new theme button
 	g_signal_connect_swapped (G_OBJECT (GetWidget ("new-theme")), "clicked", G_CALLBACK (on_new_theme), this);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
