@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * atom.h 
+ * atom.h
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -33,10 +33,11 @@
 /*!\file*/
 namespace gcu
 {
-	
+
 class Bond;
 class Cycle;
 class AtomMatchState;
+class Vector;
 
 /*!\class Atom gcu/atom.h
 This class is used to represent atoms.
@@ -95,7 +96,7 @@ Multiplies all three coordinates of this Atom by ZoomFactor.
 Retrieves the coordinates of this Atom.
 @return true if successful and false if an error occurs (if x or y is NULL).
 */
-	virtual bool GetCoords (double *x, double *y, double *z = NULL) const;
+	bool GetCoords (double *x, double *y, double *z = NULL) const;
 /*!
 @param x the new x coordinate of the Atom.
 @param y the new y coordinate of the Atom.
@@ -145,28 +146,37 @@ Removes a Bond.
 @return the x coordinate of this Atom.
 */
 	double x () const {return m_x;}
+	double &x () {return m_x;}
 /*!
 @return the y coordinate of this Atom.
 */
 	double y () const {return m_y;}
+	double &y () {return m_y;}
 /*!
 @return the z coordinate of this Atom.
 */
 	double z () const {return m_z;}
+	double &z () {return m_z;}
+/*!
+@return a Vector with the three Atom space coordinates.
+*/
+	Vector GetVector () const;
 /*!
 @param i a C++ std::map iterator.
 
 Use this function to retrieve the first Bond of this Atom and initialize the iterator.
 @return the first Bond of this Atom or NULL if the Atom has is not bonded.
 */
-	Bond* GetFirstBond (std::map<Atom*, Bond*>::iterator& i);
+	Bond *GetFirstBond (std::map < Atom *, Bond * >::iterator& i);
+	Bond const *GetFirstBond (std::map< Atom *, Bond * >::const_iterator& i) const;
 /*!
 @param i a C++ std::map iterator initialized by Atom::GetFirstBond.
 
 Use this method to iterate through the list of Bond instances of this Atom.
 @return the next Bond of this Atom or NULL.
 */
-	Bond* GetNextBond (std::map<Atom*, Bond*>::iterator& i);
+	Bond *GetNextBond (std::map<Atom*, Bond*>::iterator& i);
+	Bond const *GetNextBond (std::map< Atom *, Bond * >::const_iterator& i) const;
 /*!
 @param pAtom a pointer to an Atom instance.
 @return a pointer to the Bond shared by pAtom and this Atom if it exists or NULL.
@@ -255,6 +265,11 @@ and return its result.
 */
 	virtual bool Match (Atom *atom, AtomMatchState &state);
 
+/*!
+@return the localized object generic name.
+*/
+	std::string Name ();
+
 protected:
 /*!
 The atomic number of the Atom.
