@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * libs/gcu/chain.h 
+ * libs/gcu/chain.h
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -92,7 +92,7 @@ if pAtom is NULL.
 The destructor.
 */
 	virtual ~Chain();
-	
+
 /*!
 @param pAtom an atom.
 
@@ -137,6 +137,7 @@ Extracts a sub-chain to the chain variable which should be empty before the call
 Reverses the chain order.
 */
 	void Reverse ();
+	void Append (Chain& chain);
 /*!
 @param start an atom.
 @param end an atom.
@@ -182,6 +183,7 @@ Adds the two atoms and the bond between them to the chain. The two atoms must be
 @return the localized object generic name.
 */
 	std::string Name ();
+	unsigned BuildLength (unsigned *cycle_size = NULL, unsigned *cycle_pos = NULL);
 
 protected:
 /*!
