@@ -91,7 +91,7 @@ Displays the molecule using OpenGL.
 @param uri the uri of the molecule file.
 @param mime_type the mime type of the molecule file.
 
-Loads a molecule from the provided uri using OpenBabel.
+Loads a molecule from the provided uri.
 */
 	void Load (char const *uri, char const *mime_type);
 
@@ -101,7 +101,7 @@ Loads a molecule from the provided uri using OpenBabel.
 @param size the size of the data. If nul, the size will be evaluated from
 the string length.
 
-Loads a molecule from the provided data using OpenBabel.
+Loads a molecule from the provided data.
 */
 	void LoadData (char const *data, char const *mime_type, size_t size = 0);
 
@@ -118,8 +118,8 @@ Clears the document.
 	void Clear ();
 	virtual GLView *CreateView ();
 
-private:
-	Molecule *m_Mol;
+	static Display3DMode Display3DModeFromString (char const *name);
+	static char const *Display3DModeAsString (Display3DMode mode);
 
 /*!\fn SetDisplay3D(Display3DMode mode)
 @param mode: the new mode.
@@ -132,7 +132,8 @@ Sets the display mode to one of the available Display3DMode values.
 /*!\fn GetRefDisplay3D()
 @return the current mode as a reference.
 */
-GCU_PROP (Display3DMode, Display3D);
+GCU_PROP (Display3DMode, Display3D)
+GCU_RO_PROP (Molecule *, Mol)
 };
 
 }	// namespace gcu
