@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemisty Utils
- * macros.h 
+ * macros.h
  *
- * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,7 +27,7 @@
 
 #include <goffice/goffice.h>
 
-/*!\file */ 
+/*!\file */
 /*!\def GCU_PROP()
 Defines a private member with appropriate get/set methods.
 GCU_PROP((Type,Foo) expands to one private member:
@@ -79,7 +79,7 @@ private:	\
 
 /*!\def GCU_RO_PROP()
 Defines a private member with an appropriate get method. RO stands for Read Only. The member
-can't be modified from outside the class it belongs too or a friend class.
+can't be modified from outside the class it belongs to or a friend class.
 GCU_RO_PROP(Type,Foo) expands to one private member:
 \code
 	Type m_Foo;
@@ -96,9 +96,28 @@ public:	\
 private:	\
 	type m_##member;
 
+/*!\def GCU_RO_STATIC_PROP()
+Defines a static private member with an appropriate get method. RO stands for Read Only. The member
+can't be modified from outside the class it belongs to or a friend class.
+GCU_RO_STATIC_PROP(Type,Foo) expands to one private member:
+\code
+	static Type m_Foo;
+\endcode
+
+and one public method:
+\code
+	Type GetFoo() const;
+\endcode
+*/
+#define GCU_RO_STATIC_PROP(type,member) \
+public:	\
+	type Get##member (void) const {return m_##member;}	\
+private:	\
+	static type m_##member;
+
 /*!\def GCU_RO_POINTER_PROP()
 Defines a private pointer member an with appropriate get method. RO stands for Read Only. The member
-can't be modified from outside the class it belongs too or a friend class.
+can't be modified from outside the class it belongs to or a friend class.
 GCU_RO_POINTER_PROP((Type,Foo) expands to one private member:
 \code
 	Type *m_Foo;
@@ -161,8 +180,7 @@ This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs or if the value is 0,
 \a defaultval is used instead.\n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
@@ -175,8 +193,7 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs, \a defaultval is used instead.\n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
@@ -189,8 +206,7 @@ occurs or if the value is 0, \a defaultval is used instead.\n
 The resuting value (which might be the default value) is then passed
 to \a func and the result is copied to \a target. \n
 If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
-have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
-member called m_ConfClient, and the code must provide a GError *error initially
+have a GOConfNode called m_ConfNode, and the code must provide a GError *error initially
 set to NULL (GConf version only).
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
@@ -207,7 +223,7 @@ This macro gets the string value associated to \a key, and
 copies it to \a target. If an error occurs, \a defaultval is used instead.\n
 If \a target is not NULL when entering the macro, it is deallocated using g_free
 and set to NULL before calling gconf_client_get_string.\n
-Calling class must have a GConfClient member called m_ConfClient, and the code
+Calling class must have a GOConfNode called m_ConfNode, and the code
 must provide a GError *error initially set to NULL.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
@@ -223,8 +239,7 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 /*!\def GCU_UPDATE_KEY()
 This macro updates a value of type \a type associated to \a key, and
 copies it to \a target. \a action is called after setting the target?
-It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
-on the GOffice library version.
+It also needs a GOConfNode* called node.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #define GCU_UPDATE_KEY(key,type,target,action) \
@@ -237,8 +252,7 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 /*!\def GCU_UPDATE_STRING_KEY()
 This macro updates a string value associated to \a key, and
 copies it to \a target. \a action is called after setting the target?
-It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
-on the GOffice library version.
+It also needs a GOConfNode* called node.
 The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #define GCU_UPDATE_STRING_KEY(key,target,action) \
@@ -248,4 +262,9 @@ The real key is obtained by appending the value of ROOTDIR to \a key.
 		return; \
 	}
 
+#define CC2XML(x) reinterpret_cast <xmlChar const *> (x)
+#define C2XML(x) reinterpret_cast <xmlChar *> (x)
+#define XML2CC(x) reinterpret_cast <char const *> (x)
+#define XML2C(x) reinterpret_cast <char *> (x)
+
 #endif	//	GCU_MACROS_H
