@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * matrix.h 
+ * matrix.h
  *
- * Copyright (C) 2000-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -21,12 +21,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
- 
+
 #ifndef GCU_MATRIX_H
 #define GCU_MATRIX_H
 
-#include <openbabel/math/vector3.h>
-
 /*!\file*/
 namespace gcu
 {
@@ -41,14 +39,14 @@ Possible values are:
 	- rotation: matrix representing the rotation to apply to the solid.
 	.
 This enumeration is used in one of the constructors (Matrix(Psi, Theta, Phi, Type)) of class Matrix.
-*/	
+*/
 
 enum MatrixType {euler, antieuler, rotation};
 
 /*!\class Matrix gcu/matrix.h
 This class provides some operations related to rotation of 	a solid in space. The matrices are 3x3.
 */
-class Matrix  
+class Matrix
 {
 public:
 
@@ -58,16 +56,30 @@ Default constructor. Initialized to unit matrix.
 	Matrix ();
 /*!
 @param d a number.
+
 Constructs a scalar matrix. Initializes diagonal elements to \a d and other elements to 0.
 */
 	Matrix (double d);
+/*!
+@param d a table of numbers.
+
+Constructs a matrix from the values in \a d.
+*/
 	Matrix (double d[3][3]);
 /*!
 @param m a matrix.
+
 Copy contructor.
 */
 	Matrix (Matrix const &m);
+/*!
+@param v1 a Vector.
+@param v2 a Vector.
+@param v3 a Vector.
+@param as_rows whether the Vector arguments are used as rows or columns.
 
+Constructs a Matrix from three Vector arguments.
+*/
 	Matrix (Vector const &v1, Vector const &v2, Vector const &v3, bool as_rows = true);
 /*!
 The destructor of Matrix.
@@ -135,11 +147,35 @@ Initially, dx, dy and dz are the components of the vector to transform (multiply
 after execution of this method, dx, dy and dz are the components of the transformed vector. So initial values are lost.
 */
 	void Transform (double &dx, double &dy , double &dz) const;
+/*!
+@param v a Vector.
+
+Multiplies \a v by the Matrix.
+@return the result of the multiplication.
+*/
 	Vector operator* (Vector const &v) const;
-	OpenBabel::vector3 operator* (OpenBabel::vector3 const &v) const;
+/*!
+@param v a Vector.
+
+Multiplies \a v by the Matrix using OpenGL coordinates conventions.
+@return the result of the multiplication.
+*/
+	Vector glmult (Vector const &v) const;
+/*!
+@param i the row.
+@param j the column.
+
+return the value at row \a i and column \a j as a reference.
+*/
 	double &operator() (unsigned i, unsigned j) {return x[i][j];}
+/*!
+@param i the row.
+@param j the column.
+
+return the value at row \a i and column \a j.
+*/
 	double operator() (unsigned i, unsigned j) const {return x[i][j];}
-	
+
 private:
 	double x[3][3];
 };
