@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * CDXML files loader plugin
- * cdxml.cc 
+ * cdxml.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -32,6 +32,7 @@
 #include <gcu/loader.h>
 #include <gcu/molecule.h>
 #include <gcu/objprops.h>
+#include <gcu/xml-utils.h>
 
 #include <goffice/app/module-plugin-defs.h>
 #include <gsf/gsf-libxml.h>
@@ -46,6 +47,7 @@
 #include <cstring>
 
 #include <iostream>
+#include <sstream>
 
 using namespace std;
 using namespace gcu;
@@ -65,18 +67,18 @@ public:
 	virtual ~CDXMLLoader ();
 
 	ContentType Read (Document *doc, GsfInput *in, char const *mime_type, GOIOContext *io);
-	bool Write (Object *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
+	bool Write (Object const *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
 
 private:
-	bool WriteObject (xmlDocPtr xml, xmlNodePtr node, Object *object, GOIOContext *io);
+	bool WriteObject (xmlDocPtr xml, xmlNodePtr node, Object const *object, GOIOContext *io);
 	static void AddIntProperty (xmlNodePtr node, char const *id, int value);
 	static void AddStringProperty (xmlNodePtr node, char const *id, string &value);
-	static bool WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
-	static bool WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
-	static bool WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s);
+	static bool WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, GOIOContext *s);
+	static bool WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, GOIOContext *s);
+	static bool WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, GOIOContext *s);
 
 private:
-	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object *, GOIOContext *)> m_WriteCallbacks;
+	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object const *, GOIOContext *)> m_WriteCallbacks;
 	map <unsigned, GOColor> m_Colors;
 	map <unsigned, CDXMLFont> m_Fonts;
 	map <string, unsigned> m_SavedIds;
@@ -164,6 +166,7 @@ cdxml_fragment_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
 	Object *obj = state->app->CreateObject ("molecule", state->cur.top ());
 	state->cur.push (obj);
+	state->doc->ObjectLoaded (obj);
 }
 
 static void
@@ -252,6 +255,7 @@ cdxml_bond_start (GsfXMLIn *xin, xmlChar const **attrs)
 		attrs++;
 	}
 	state->cur.push (obj);
+	state->doc->ObjectLoaded (obj);
 }
 
 static void
@@ -260,6 +264,7 @@ cdxml_text_start (GsfXMLIn *xin, xmlChar const **attrs)
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
 	Object *obj = state->app->CreateObject ("text", state->cur.top ());
 	state->cur.push (obj);
+	state->doc->ObjectLoaded (obj);
 	char *lowered;
 	map<string, unsigned>::iterator it;
 	while (*attrs)
@@ -322,7 +327,7 @@ cdxml_string_start (GsfXMLIn *xin, xmlChar const **attrs)
 		else if (state->attributes & 0x40)
 			state->markup += "<sup>";
 	}
-		
+
 	// TODO: parse attributes
 }
 
@@ -336,8 +341,9 @@ cdxml_string_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 		// for now put all numbers as subscripts
 		// FIXME: fix this kludgy code
 		int cur = 0, size = strlen (xin->content->str);
-		char *new_size = g_strdup_printf ("%g", strtod (state->size.c_str (), NULL) / 1.5);
-		char *height = g_strdup_printf ("%g", strtod (state->size.c_str (), NULL) / 3.);
+		char new_size[G_ASCII_DTOSTR_BUF_SIZE], height[G_ASCII_DTOSTR_BUF_SIZE];
+		g_ascii_dtostr (new_size, G_ASCII_DTOSTR_BUF_SIZE, g_ascii_strtod (state->size.c_str (), NULL) / 1.5);
+		g_ascii_dtostr (height, G_ASCII_DTOSTR_BUF_SIZE, g_ascii_strtod (state->size.c_str (), NULL) / 3.);
 		while (cur < size) {
 			while (cur < size && (xin->content->str[cur] < '0' || xin->content->str[cur] > '9'))
 				state->markup += xin->content->str[cur++];
@@ -374,8 +380,6 @@ cdxml_string_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 					opened = false;
 			}
 		}
-		g_free (new_size);
-		g_free (height);
 	} else {
 		state->markup += xin->content->str;
 		if (state->attributes & 0x20)
@@ -453,7 +457,7 @@ fragment_done (G_GNUC_UNUSED GsfXMLIn *xin, CDXMLReadState *state)
 						switch (valence) {
 						case 2: {
 							/* remove the first atom and replace it by a pseudo-atom, then add the residue
-							this helps with things begining with an oxygen or a sulfur, but might be 
+							this helps with things begining with an oxygen or a sulfur, but might be
 							not enough n other cases */
 							double x, y;
 							a2->GetCoords (&x, &y);
@@ -538,6 +542,7 @@ cdxml_node_start (GsfXMLIn *xin, xmlChar const **attrs)
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
 	Object *obj = state->app->CreateObject ("atom", state->cur.top ());
 	obj->SetProperty (GCU_PROP_ATOM_Z, "6");
+	state->doc->ObjectLoaded (obj);
 	map<string, unsigned>::iterator it;
 	bool fragment = false;
 	while (*attrs) {
@@ -573,6 +578,7 @@ cdxml_node_start (GsfXMLIn *xin, xmlChar const **attrs)
 		if (NULL == doc)
 			doc = gsf_xml_in_doc_new (atom_dtd, NULL);
 		state->cur.push (obj); // push it twice in that case
+		state->doc->ObjectLoaded (obj);
 		gsf_xml_in_push_state (xin, doc, state, (GsfXMLInExtDtor) fragment_done, attrs);
 	}
 }
@@ -619,6 +625,7 @@ cdxml_group_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 	Object *obj = state->app->CreateObject ("group", state->cur.top ());
 	obj->Lock ();
 	state->cur.push (obj);
+	state->doc->ObjectLoaded (obj);
 }
 
 static void
@@ -631,9 +638,10 @@ cdxml_graphic_start (GsfXMLIn *xin, xmlChar const **attrs)
 	while (*attrs) {
 		if (!strcmp ((char const *) *attrs, "id"))
 			Id = atoi ((char const *) attrs[1]);
-		else if (!strcmp ((char const *) *attrs, "BoundingBox"))
-			sscanf ((char const *) attrs[1], "%lg %lg %lg %lg", &x1, &y1, &x0, &y0);
-		else if (!strcmp ((char const *) *attrs, "GraphicType")) {
+		else if (!strcmp ((char const *) *attrs, "BoundingBox")) {
+			istringstream str (reinterpret_cast <char const *> (attrs[1]));
+			str >> x1 >> y1 >> x0 >> y0;
+		} else if (!strcmp ((char const *) *attrs, "GraphicType")) {
 			if (!strcmp ((char const *) attrs[1], "Line"))
 				type = 1;
 		} else if (!strcmp ((char const *) *attrs, "ArrowType")) {
@@ -651,36 +659,36 @@ cdxml_graphic_start (GsfXMLIn *xin, xmlChar const **attrs)
 		attrs+=2;
 	}
 	if (type == 1) {
-		char *buf = NULL;
 		Object *obj = NULL;
+		ostringstream str;
 		switch (arrow_type) {
 		case 1:
 		case 2:
 			obj = state->app->CreateObject ("reaction-arrow", state->cur.top ());
-			buf = g_strdup_printf ("ra%d", Id);
+			str << "ra" << Id;
 			break;
 		case 4:
 			obj = state->app->CreateObject ("mesomery-arrow", state->cur.top ());
-			buf = g_strdup_printf ("ma%d", Id);
+			str << "ma" << Id;
 			break;
 		case 8:
 			obj = state->app->CreateObject ("reaction-arrow", state->cur.top ());
-			buf = g_strdup_printf ("ra%d", Id);
+			str << "ra" << Id;
 			obj->SetProperty (GCU_PROP_REACTION_ARROW_TYPE, "double");
 			break;
 		case 32:
 			obj = state->app->CreateObject ("retrosynthesis-arrow", state->cur.top ());
-			buf = g_strdup_printf ("rsa%d", Id);
+			str << "rsa" << Id;
 			break;
 		default:
 			break;
 		}
 		if (obj) {
-			obj->SetId (buf);
-			g_free (buf);
-			buf = g_strdup_printf ("%g %g %g %g", x0, y0, x1, y1);
-			obj->SetProperty (GCU_PROP_ARROW_COORDS, buf);
-			g_free (buf);
+			obj->SetId (str.str ().c_str ());
+			ostringstream str_;
+			str_ << x0 << " " << y0 << " " << x1 << " " << y1;
+			obj->SetProperty (GCU_PROP_ARROW_COORDS, str_.str ().c_str ());
+			state->doc->ObjectLoaded (obj);
 		}
 	}
 }
@@ -798,7 +806,7 @@ static int cb_xml_to_vfs (GsfOutput *output, const guint8* buf, int nb)
 		return gsf_output_write (output, nb, buf)? nb: 0;
 }
 
-bool CDXMLLoader::WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, G_GNUC_UNUSED GOIOContext *s)
+bool CDXMLLoader::WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, G_GNUC_UNUSED GOIOContext *s)
 {
 	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("n"), NULL);
 	xmlAddChild (parent, node);
@@ -806,20 +814,20 @@ bool CDXMLLoader::WriteAtom (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr pare
 	AddIntProperty (node, "id", loader->m_MaxId++);
 	string prop = obj->GetProperty (GCU_PROP_POS2D);
 	AddStringProperty (node, "p", prop);
-	AddIntProperty (node, "Z", loader->m_Z++);	
+	AddIntProperty (node, "Z", loader->m_Z++);
 	prop = obj->GetProperty (GCU_PROP_ATOM_Z);
 	if (prop != "6")
 		AddStringProperty (node, "Element", prop);
 	return true;
 }
 
-bool CDXMLLoader::WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, G_GNUC_UNUSED GOIOContext *s)
+bool CDXMLLoader::WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, G_GNUC_UNUSED GOIOContext *s)
 {
 	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("b"), NULL);
 	xmlAddChild (parent, node);
 	loader->m_SavedIds[obj->GetId ()] = loader->m_MaxId;
 	AddIntProperty (node, "id", loader->m_MaxId++);
-	AddIntProperty (node, "Z", loader->m_Z++);	
+	AddIntProperty (node, "Z", loader->m_Z++);
 	string prop = obj->GetProperty (GCU_PROP_BOND_BEGIN);
 	AddIntProperty (node, "B", loader->m_SavedIds[prop]);
 	prop = obj->GetProperty (GCU_PROP_BOND_END);
@@ -845,15 +853,15 @@ bool CDXMLLoader::WriteBond (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr pare
 	return true;
 }
 
-bool CDXMLLoader::WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object *obj, GOIOContext *s)
+bool CDXMLLoader::WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr parent, Object const *obj, GOIOContext *s)
 {
 	xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("fragment"), NULL);
 	xmlAddChild (parent, node);
 	loader->m_SavedIds[obj->GetId ()] = loader->m_MaxId;
 	AddIntProperty (node, "id", loader->m_MaxId++);
 	// save atoms
-	std::map <std::string, Object *>::iterator i;
-	Object *child = obj->GetFirstChild (i);
+	std::map <std::string, Object *>::const_iterator i;
+	Object const *child = obj->GetFirstChild (i);
 	while (child) {
 		if (child->GetType () == AtomType && !loader->WriteObject (xml, node, child, s))
 			return false;
@@ -876,15 +884,15 @@ bool CDXMLLoader::WriteMolecule (CDXMLLoader *loader, xmlDocPtr xml, xmlNodePtr
 	return true;
 }
 
-bool CDXMLLoader::WriteObject (xmlDocPtr xml, xmlNodePtr node, Object *object, GOIOContext *io)
+bool CDXMLLoader::WriteObject (xmlDocPtr xml, xmlNodePtr node, Object const *object, GOIOContext *io)
 {
 	string name = Object::GetTypeName (object->GetType ());
-	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object *, GOIOContext *)>::iterator i = m_WriteCallbacks.find (name);
+	map <string, bool (*) (CDXMLLoader *, xmlDocPtr, xmlNodePtr, Object const *, GOIOContext *)>::iterator i = m_WriteCallbacks.find (name);
 	if (i != m_WriteCallbacks.end ())
 		return (*i).second (this, xml, node, object, io);
 	// if we don't save the object iself, try to save its children
-	std::map <std::string, Object *>::iterator j;
-	Object *child = object->GetFirstChild (j);
+	std::map <std::string, Object *>::const_iterator j;
+	Object const *child = object->GetFirstChild (j);
 	while (child) {
 		if (!WriteObject (xml, node, child, io))
 			return false;
@@ -894,22 +902,16 @@ bool CDXMLLoader::WriteObject (xmlDocPtr xml, xmlNodePtr node, Object *object, G
 					either in this code or in the cml schema */
 }
 
-void CDXMLLoader::AddIntProperty (xmlNodePtr node, char const *id, int value)
-{
-	char *buf = g_strdup_printf("%d", value);
-	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar const *> (buf));
-	g_free (buf);
-}
-
 void CDXMLLoader::AddStringProperty (xmlNodePtr node, char const *id, string &value)
 {
 	xmlNewProp (node, reinterpret_cast <xmlChar const *> (id), reinterpret_cast <xmlChar const *> (value.c_str ()));
 }
 
-bool CDXMLLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io, G_GNUC_UNUSED ContentType type)
+bool CDXMLLoader::Write  (Object const *obj, GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io, G_GNUC_UNUSED ContentType type)
 {
 	map<string, CDXMLFont> fonts;
-	Document *doc = dynamic_cast <Document *> (obj);
+	// FIXME: should be able to export a molecule or a reaction
+	Document const *doc = dynamic_cast <Document const *> (obj);
 	xmlNodePtr colors, fonttable, page;
 	if (!doc || !out)
 		return false;
@@ -939,7 +941,7 @@ bool CDXMLLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED char const
 	// determine the bond length and scale the document appropriately
 	string prop = doc->GetProperty (GCU_PROP_THEME_BOND_LENGTH);
 	double scale = strtod (prop.c_str (), NULL);
-	doc->SetScale (scale / 30.);
+	const_cast <Document *> (doc)->SetScale (scale / 30.);
 	xmlNewProp (xml->children, reinterpret_cast <xmlChar const *> ("BondLength"),
 	            reinterpret_cast <xmlChar const *> ("30"));
 	// add color table
@@ -952,8 +954,8 @@ bool CDXMLLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED char const
 	page = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("page"), NULL);
 	xmlAddChild (xml->children, page);
 	// build tree from children
-	std::map <std::string, Object *>::iterator i;
-	Object *child = doc->GetFirstChild (i);
+	std::map <std::string, Object *>::const_iterator i;
+	Object const *child = doc->GetFirstChild (i);
 	while (child) {
 		if (!WriteObject (xml, page, child, io)) {
 			xmlFreeDoc (xml);
@@ -969,22 +971,16 @@ bool CDXMLLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED char const
 	for (color = m_Colors.begin (); color != end_color; color++) {
 		xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("color"), NULL);
 		xmlAddChild (colors, node);
-		char *buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_R ((*color).second));
-		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("r"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_G ((*color).second));
-		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("g"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", GO_COLOR_DOUBLE_B ((*color).second));
-		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("b"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
+		WriteFloat (node, "r", GO_COLOR_DOUBLE_R ((*color).second));
+		WriteFloat (node, "g", GO_COLOR_DOUBLE_G ((*color).second));
+		WriteFloat (node, "b", GO_COLOR_DOUBLE_B ((*color).second));
 	}
 	// write fonts
 	map <unsigned, CDXMLFont>::iterator font, end_font = m_Fonts.end ();
 	for (font = m_Fonts.begin (); font != end_font; font++) {
 		xmlNodePtr node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
 		xmlAddChild (fonttable, node);
-		AddIntProperty (node, "id", (*font).second.index);
+		WriteInt (node, "id", (*font).second.index);
 		AddStringProperty (node, "charset", (*font).second.encoding);
 		AddStringProperty (node, "name", (*font).second.name);
 	}
