@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint bonds plugin
  * bondtool.cc
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -38,7 +38,7 @@
 #include <gccv/line.h>
 #include <gccv/squiggle.h>
 #include <gccv/wedge.h>
-#include <gcu/ui-builder.h>
+#include <gcugtk/ui-builder.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 
@@ -360,7 +360,7 @@ void gcpBondTool::OnRelease ()
 				pBond->IncOrder ();
 			m_pObject = pBond;
 			m_bChanged = true;
-			FinalizeBond (); 
+			FinalizeBond ();
 			gcp::Atom* pAtom = (gcp::Atom*) ((gcp::Bond*) m_pObject)->GetAtom (0);
 			pAtom->Update ();
 			m_pView->Update (pAtom);
@@ -489,7 +489,7 @@ void gcpBondTool::SetLength (double length)
 
 GtkWidget *gcpBondTool::GetPropertyPage ()
 {
-	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/bond.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/bond.ui", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_AngleBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-angle"));
