@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint bonds plugin
- * bondtool.h 
+ * bondtool.h
  *
  * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -38,7 +38,7 @@ class gcpBondTool: public gcp::Tool
 public:
 	gcpBondTool (gcp::Application *App, std::string ToolId = "Bond", unsigned nPoints = 2);
 	virtual ~gcpBondTool ();
-	
+
 	bool OnClicked ();
 	void OnDrag ();
 	void OnRelease ();
@@ -99,13 +99,15 @@ public:
 	gcpDownBondTool (gcp::Application *App);
 	virtual ~gcpDownBondTool ();
 
-	void OnConfigChanged ();
-
 protected:
 	virtual void Draw ();
 	virtual void UpdateBond ();
 	virtual void FinalizeBond ();
 	virtual void SetType (gcp::Bond* pBond);
+
+private:
+	GOConfNode *m_ConfNode;
+	guint m_NotificationId;
 };
 
 class gcpSquiggleBondTool: public gcpBondTool
