@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint selection plugin
  * selectiontool.cc
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -33,6 +33,7 @@
 #include <gcp/theme.h>
 #include <gcp/view.h>
 #include <gcp/window.h>
+#include <gcugtk/ui-manager.h>
 #include <gccv/canvas.h>
 #include <gccv/group.h>
 #include <gccv/rectangle.h>
@@ -78,12 +79,12 @@ gcpSelectionTool::gcpSelectionTool (gcp::Application *App): gcp::Tool (App, "Sel
 gcpSelectionTool::~gcpSelectionTool ()
 {
 	if (m_UIManager)
-		g_object_unref (m_UIManager);
+		delete m_UIManager;
 }
 
 bool gcpSelectionTool::OnClicked ()
 {
-	gcp::Window *win = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *win = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	if (m_pObject) {
 		Object* pObj = m_pObject->GetGroup ();
 		if (pObj)
@@ -119,7 +120,7 @@ bool gcpSelectionTool::OnClicked ()
 		else
 			m_dAngleInit = atan (-m_y0 / m_x0) * 180 / M_PI;
 		if (m_x0 < 0) m_dAngleInit += 180.;
-		std::list<Object*>::iterator i, end = m_pData->SelectedObjects.end ();
+		std::set < Object * >::iterator i, end = m_pData->SelectedObjects.end ();
 		gcp::Document* pDoc = m_pView->GetDoc ();
 		m_pOp = pDoc-> GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 		for (i = m_pData->SelectedObjects.begin (); i != end; i++)
@@ -181,7 +182,7 @@ void gcpSelectionTool::OnRelease ()
 	m_pApp->ClearStatus ();
 	if (m_pObject) {
 		if (m_bRotate) {
-			std::list<Object*>::iterator i, end = m_pData->SelectedObjects.end ();
+			std::set < Object * >::iterator i, end = m_pData->SelectedObjects.end ();
 			gcp::Document* pDoc = m_pView->GetDoc ();
 			for (i = m_pData->SelectedObjects.begin (); i != end; i++)
 				m_pOp->AddObject (*i,1);
@@ -247,10 +248,13 @@ void gcpSelectionTool::Activate ()
 
 bool gcpSelectionTool::Deactivate ()
 {
+	std::map <gcp::WidgetData *, guint>::iterator i;
 	while (!SelectedWidgets.empty ())
 	{
-		SelectedWidgets.front ()->UnselectAll ();
-		SelectedWidgets.pop_front ();
+		i = SelectedWidgets.begin ();
+		(*i).first->UnselectAll ();
+		g_signal_handler_disconnect ((*i).first->Canvas, (*i).second);
+		SelectedWidgets.erase (i);
 	}
 	return true;
 }
@@ -260,7 +264,7 @@ void gcpSelectionTool::AddSelection (gcp::WidgetData* data)
 	gcp::WidgetData *d = m_pData;
 	m_pData = data;
 	m_pView = data->m_View;
-	gcp::Window *win = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *win = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	if (m_pData->HasSelection()) {
 		GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
 		m_pView->OnCopySelection (m_pData->Canvas, clipboard);
@@ -269,18 +273,21 @@ void gcpSelectionTool::AddSelection (gcp::WidgetData* data)
 			win->ActivateActionWidget ("/MainMenu/EditMenu/Cut", true);
 			win->ActivateActionWidget ("/MainMenu/EditMenu/Erase", true);
 		}
+		std::map <gcp::WidgetData *, guint>::iterator i;
+		if (SelectedWidgets.find (m_pData) == SelectedWidgets.end ())
+			SelectedWidgets[m_pData] = g_signal_connect (m_pData->Canvas, "destroy", G_CALLBACK (OnWidgetDestroyed), this);
+		if (d) {
+			m_pView = d->m_View;
+			m_pData = d;
+		}
+		// If the selection is made of two molecules, activate the merge tool
+		if (m_UIManager) {
+			std::set < Object * >::iterator i = m_pData->SelectedObjects.begin ();
+			gtk_widget_set_sensitive (m_MergeBtn, ((m_pData->SelectedObjects.size () == 2) &&
+				((*i++)->GetType () == MoleculeType) &&
+				((*i)->GetType () == MoleculeType)));
+		}
 	}
-	SelectedWidgets.remove (m_pData);
-	SelectedWidgets.push_front (m_pData);
-	if (d) {
-		m_pView = d->m_View;
-		m_pData = d;
-	}
-	// If the selection is made of two molecules, activate the merge tool
-	if (m_UIManager)
-		gtk_widget_set_sensitive (m_MergeBtn, ((m_pData->SelectedObjects.size () == 2) &&
-			(m_pData->SelectedObjects.front ()->GetType () == MoleculeType) &&
-			(m_pData->SelectedObjects.back ()->GetType () == MoleculeType)));
 }
 
 void gcpSelectionTool::OnFlip (bool horizontal)
@@ -298,7 +305,7 @@ void gcpSelectionTool::OnFlip (bool horizontal)
 	m_cy = (rect.y0 + rect.y1) / 2.;
 	m_x = (horizontal)? -1.: 1.;
 	Matrix2D m(m_x, 0., 0., -m_x);
-	std::list<Object*>::iterator i, end = m_pData->SelectedObjects.end ();
+	std::set < Object * >::iterator i, end = m_pData->SelectedObjects.end ();
 	gcp::Document* pDoc = m_pView->GetDoc ();
 	gcp::Theme *pTheme = pDoc->GetTheme ();
 	m_pOp = pDoc-> GetNewOperation (gcp::GCP_MODIFY_OPERATION);
@@ -325,8 +332,9 @@ void gcpSelectionTool::Merge ()
 		GtkWidget *w = m_pView->GetWidget ();
 		m_pData = (gcp::WidgetData*) g_object_get_data (G_OBJECT (w), "data");
 	}
-	pMol0 = (gcp::Molecule*) m_pData->SelectedObjects.front ();
-	pMol1 = (gcp::Molecule*) m_pData->SelectedObjects.back ();
+	std::set < gcu::Object * >::iterator i = m_pData->SelectedObjects.begin ();
+	pMol0 = (gcp::Molecule*) (*i++);
+	pMol1 = static_cast < gcp::Molecule * > (*i);
 	m_pOp = pDoc-> GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 	m_pOp->AddObject (pMol0, 0);
 	m_pOp->AddObject (pMol1, 0);
@@ -364,7 +372,7 @@ void gcpSelectionTool::CreateGroup ()
 	Object *pObj = Object::CreateObject (Object::GetTypeName (m_Type), pDoc);
 	try {
 		m_pOp = pDoc-> GetNewOperation (gcp::GCP_MODIFY_OPERATION);
-		std::list<Object*>::iterator i, end = m_pData->SelectedObjects.end();
+		std::set < Object * >::iterator i, end = m_pData->SelectedObjects.end();
 		for (i = m_pData->SelectedObjects.begin (); i != end; i++)
 			m_pOp->AddObject (*i,0);
 		if (!pObj->Build (m_pData->SelectedObjects)) {
@@ -378,6 +386,7 @@ void gcpSelectionTool::CreateGroup ()
 			return;
 		}
 		m_pView->Update (pObj);
+		m_pView->EnsureSize ();
 		m_pData->UnselectAll ();
 		m_pData->SetSelected (pObj);
 		AddSelection (m_pData);
@@ -395,17 +404,17 @@ void gcpSelectionTool::CreateGroup ()
 	}
 }
 
-bool gcpSelectionTool::OnRightButtonClicked (GtkUIManager *UIManager)
+bool gcpSelectionTool::OnRightButtonClicked (gcu::UIManager *UIManager)
 {
-	// first destroy the GtkUIManager
+	GtkUIManager *uim = static_cast < gcugtk::UIManager * > (UIManager)->GetUIManager ();
 	if (m_pData->SelectedObjects.size () > 1) {
 		GtkActionGroup *group = gtk_action_group_new ("selection");
 		GtkAction *action = gtk_action_new ("group", _("Group and/or align objects"), NULL, NULL);
 		gtk_action_group_add_action (group, action);
-		m_uiIds.push_front (gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='group'/></popup></ui>", -1, NULL));
+		m_uiIds.push_front (gtk_ui_manager_add_ui_from_string (uim, "<ui><popup><menuitem action='group'/></popup></ui>", -1, NULL));
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (on_group), this);
 		set<TypeId> possible_types, types, wrong_types;
-		list<Object*>::iterator  i = m_pData->SelectedObjects.begin (),
+		set < Object * >::iterator  i = m_pData->SelectedObjects.begin (),
 												end = m_pData->SelectedObjects.end ();
 		(*i)->GetPossibleAncestorTypes (possible_types);
 		set<TypeId>::iterator type;
@@ -427,11 +436,11 @@ bool gcpSelectionTool::OnRightButtonClicked (GtkUIManager *UIManager)
 				action = gtk_action_new ("create_group", label.c_str (), NULL, NULL);
 				gtk_action_group_add_action (group, action);
 				char buf[] = "<ui><popup><menuitem action='create_group'/></popup></ui>";
-				m_uiIds.push_front (gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL));
+				m_uiIds.push_front (gtk_ui_manager_add_ui_from_string (uim, buf, -1, NULL));
 				g_signal_connect_swapped (action, "activate", G_CALLBACK (on_create_group), this);
 			}
 		}
-		gtk_ui_manager_insert_action_group (UIManager, group, 0);
+		gtk_ui_manager_insert_action_group (uim, group, 0);
 		return true;
 	}
 	return false;
@@ -463,35 +472,36 @@ static const char *ui_description =
 
 GtkWidget *gcpSelectionTool::GetPropertyPage ()
 {
-	GtkWidget *box, *w;
+	GtkWidget *grid, *w;
 	GtkActionGroup *action_group;
 	GError *error;
 
-	box = gtk_vbox_new (FALSE, 0);
+	grid = gtk_grid_new ();
+	g_object_set (G_OBJECT (grid), "orientation", GTK_ORIENTATION_VERTICAL, "border-width", 6, NULL);
 	action_group = gtk_action_group_new ("SelectionToolActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), m_pApp);
 	gtk_action_group_add_toggle_actions (action_group, toggles, G_N_ELEMENTS (toggles), m_pApp);
 
-	m_UIManager = gtk_ui_manager_new ();
-	if (!gtk_ui_manager_add_ui_from_string (m_UIManager, ui_description, -1, &error))
+	m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
+	if (!gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), ui_description, -1, &error))
 	  {
 		g_message ("building property page failed: %s", error->message);
 		g_error_free (error);
-		gtk_widget_destroy (box);
+		gtk_widget_destroy (grid);
 		g_object_unref (m_UIManager);
 		m_UIManager = NULL;
 		return NULL;;
 	  }
-	gtk_ui_manager_insert_action_group (m_UIManager, action_group, 0);
-	w = gtk_ui_manager_get_widget (m_UIManager, "/Selection");
+	gtk_ui_manager_insert_action_group (m_UIManager->GetUIManager (), action_group, 0);
+	w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/Selection");
 	gtk_toolbar_set_style (GTK_TOOLBAR (w), GTK_TOOLBAR_ICONS);
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (w), false);
-	gtk_box_pack_start (GTK_BOX (box), w, false, false, 0);
-	gtk_widget_show_all (box);
-	m_MergeBtn = gtk_ui_manager_get_widget (m_UIManager, "/Selection/Merge");
+	gtk_container_add (GTK_CONTAINER (grid), w);
+	gtk_widget_show_all (grid);
+	m_MergeBtn = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/Selection/Merge");
 	gtk_widget_set_sensitive (m_MergeBtn, false);
-	return box;
+	return grid;
 }
 
 char const *gcpSelectionTool::GetHelpTag ()
@@ -500,3 +510,8 @@ char const *gcpSelectionTool::GetHelpTag ()
 		return "rotate";
 	return "selection";
 }
+
+void gcpSelectionTool::OnWidgetDestroyed (GtkWidget *widget, gcpSelectionTool *tool)
+{
+	tool->SelectedWidgets.erase (static_cast <gcp::WidgetData *> (g_object_get_data (G_OBJECT (widget), "data")));
+}
