@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/3d/view.cc 
+ * programs/3d/view.cc
  *
  * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -26,7 +26,7 @@
 #include "document.h"
 #include "view.h"
 
-gc3dView::gc3dView (gc3dDocument *Doc): gcugtk::GLView (Doc)
+gc3dView::gc3dView (gc3dDocument *Doc): gcugtk::Chem3dView (Doc)
 {
 }
 
