@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/gchemtable-app.cc 
+ * programs/gchemtable-app.cc
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,17 +27,13 @@
 #include "gchemtable-curve.h"
 #include "gchemtable-data.h"
 #include "gchemtable-elt.h"
+#include <gcugtk/filechooser.h>
+#include <gcugtk/ui-builder.h>
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
-#include <gcu/filechooser.h>
-#include <gcu/ui-builder.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <cstdlib>
 #include <cstring>
@@ -57,19 +53,9 @@ static void on_new_chart (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App)
 	App->OnNewChart (NULL);
 }
 
-static void on_electroneg_chart (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App)
+static void on_chart (GtkAction *action, GChemTableApp *App)
 {
-	App->OnNewChart ("en/Pauling");
-}
-
-static void on_radius_chart (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App)
-{
-	App->OnNewChart ("covalent");
-}
-
-static void on_affinity_chart (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App)
-{
-	App->OnNewChart ("ae");
+	App->OnNewChart (gtk_action_get_name (action));
 }
 
 static void on_no_colors (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App)
@@ -112,11 +98,6 @@ static void on_block_colors (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App
 	App->SetColorScheme ("block");
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, gpointer data)
-{
-	reinterpret_cast <Application *> (data)->OnWeb (url);
-}
-
 static void on_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *app)
 {
 	app->OnHelp ();
@@ -147,7 +128,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *app)
 	app->OnAbout ();
 }
 
-static void on_changed (G_GNUC_UNUSED GtkPeriodic* periodic, guint Z, GChemTableApp *app)
+static void on_changed (G_GNUC_UNUSED GcuPeriodic* periodic, guint Z, GChemTableApp *app)
 {
 	app->OnElement (Z);
 }
@@ -181,13 +162,27 @@ static GtkActionEntry entries[] = {
 		  N_("Use colors to display the blocks elements belong to"),
                   G_CALLBACK (on_block_colors) },
     {"ChartMenu", NULL, N_("Element charts "), NULL, NULL, NULL },
-      { "ElectronegChart", NULL, N_("Electronegativty "), NULL,
-		  N_("Create an electronegativity chart"), G_CALLBACK (on_electroneg_chart) },
-      { "RadiusChart", NULL, N_("Atomic radius"), NULL,
-		  N_("Create an atomic radius chart"), G_CALLBACK (on_radius_chart) },
-      { "AffinityChart", NULL, N_("Electon affinity"), NULL,
-		  N_("Create an electronic affinity chart"), G_CALLBACK (on_affinity_chart) },
-	  { "CustomChart", NULL, N_("Custom "), NULL,
+      { "en-Pauling", NULL, N_("Electronegativty "), NULL,
+		  N_("Create an electronegativity chart"), G_CALLBACK (on_chart) },
+      { "ae", NULL, N_("Electon affinity"), NULL,
+		  N_("Create an electronic affinity chart"), G_CALLBACK (on_chart) },
+      { "ei-1", NULL, N_("First ionization energy"), NULL,
+		  N_("Create an first ionization energy chart"), G_CALLBACK (on_chart) },
+      { "ei-2", NULL, N_("Second ionization energy"), NULL,
+		  N_("Create an second ionization energy chart"), G_CALLBACK (on_chart) },
+      { "ei-3", NULL, N_("Third ionization energy"), NULL,
+		  N_("Create an third ionization energy chart"), G_CALLBACK (on_chart) },
+      { "covalent", NULL, N_("Covalent radius"), NULL,
+		  N_("Create an atomic covalent radius chart"), G_CALLBACK (on_chart) },
+      { "vdw", NULL, N_("Van der Waals radius"), NULL,
+		  N_("Create an atomic van der Waals radius chart"), G_CALLBACK (on_chart) },
+      { "metallic", NULL, N_("Metallic radius"), NULL,
+		  N_("Create an atomic metallic radius chart"), G_CALLBACK (on_chart) },
+      { "mp", NULL, N_("Melting temperature"), NULL,
+		  N_("Create an melting temperature chart"), G_CALLBACK (on_chart) },
+      { "bp", NULL, N_("Ebullition temperature"), NULL,
+		  N_("Create an ebullition temperature chart"), G_CALLBACK (on_chart) },
+	  { "CustomChart", NULL, N_("Custom"), NULL,
 		  N_("Create a custom chart"), G_CALLBACK (on_new_chart) },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 	  { "Help", GTK_STOCK_HELP, N_("_Contents"), "F1",
@@ -222,9 +217,19 @@ static const char *ui_description =
 "        <menuitem action='BlockColors'/>"
 "      </menu>"
 "      <menu action='ChartMenu'>"
-"        <menuitem action='ElectronegChart'/>"
-"        <menuitem action='RadiusChart'/>"
-"        <menuitem action='AffinityChart'/>"
+"        <menuitem action='en-Pauling'/>"
+"        <menuitem action='ae'/>"
+"        <menuitem action='ei-1'/>"
+"        <menuitem action='ei-2'/>"
+"        <menuitem action='ei-3'/>"
+"        <separator/>"
+"        <menuitem action='covalent'/>"
+"        <menuitem action='vdw'/>"
+"        <menuitem action='metallic'/>"
+"        <separator/>"
+"        <menuitem action='mp'/>"
+"        <menuitem action='bp'/>"
+"        <separator/>"
 "        <menuitem action='CustomChart'/>"
 "      </menu>"
 "    </menu>"
@@ -239,9 +244,9 @@ static const char *ui_description =
 "  </menubar>"
 "</ui>";
 
-static void get_state_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_state_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetStateColor (Z, color);
+	App->GetStateColor (Z, rgba);
 }
 
 static void on_changed_temp (GtkRange *range, GChemTableApp *app)
@@ -254,29 +259,29 @@ static void on_changed_family (GtkComboBox *box,  GChemTableApp *app)
 	app->SetFamily (gtk_combo_box_get_active (box));
 }
 
-static void get_family_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_family_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetFamilyColor (Z, color);
+	App->GetFamilyColor (Z, rgba);
 }
 
-static void get_acidity_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_acidity_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetAcidityColor (Z, color);
+	App->GetAcidityColor (Z, rgba);
 }
 
-static void get_electroneg_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_electroneg_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetElectronegColor (Z, color);
+	App->GetElectronegColor (Z, rgba);
 }
 
-static void get_radius_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_radius_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetRadiusColor (Z, color);
+	App->GetRadiusColor (Z, rgba);
 }
 
-static void get_block_color (int Z, GdkColor *color, GChemTableApp *App)
+static void get_block_color (int Z, GdkRGBA *rgba, GChemTableApp *App)
 {
-	App->GetBlockColor (Z, color);
+	App->GetBlockColor (Z, rgba);
 }
 
 static void on_destroy (GChemTableApp *App)
@@ -285,19 +290,19 @@ static void on_destroy (GChemTableApp *App)
 	gtk_main_quit ();
 }
 
-GChemTableApp::GChemTableApp (): Application ("gchemtable")
+GChemTableApp::GChemTableApp (): gcugtk::Application ("gchemtable")
 {
-	GtkVBox* vbox;
+	GtkWidget *grid;
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW(window), _("Periodic table of the elements"));
+	gtk_window_set_title (GTK_WINDOW (window), _("Periodic table of the elements"));
+	gtk_window_set_icon_name (GTK_WINDOW (window), GetIconName ().c_str ());
 	g_signal_connect_swapped (G_OBJECT (window), "delete-event",
 		 G_CALLBACK (on_destroy),
 		 this);
 
-	g_object_set (G_OBJECT(window), "allow-shrink", FALSE, NULL);
-	
-	vbox = (GtkVBox*)gtk_vbox_new(FALSE, 0);
+	grid = gtk_grid_new ();
+	g_object_set (G_OBJECT (grid), "orientation", GTK_ORIENTATION_VERTICAL, NULL);
 	// add menus
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
@@ -313,35 +318,39 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 		exit (EXIT_FAILURE);
 	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
-	periodic = GTK_PERIODIC (gtk_periodic_new());
-	g_object_set(G_OBJECT(periodic),
-			"color-style", GTK_PERIODIC_COLOR_DEFAULT,
-			"can_unselect", true,
-			NULL);
+	gtk_container_add (GTK_CONTAINER (grid), bar);
+	periodic = GCU_PERIODIC (gcu_periodic_new());
+	g_object_set (G_OBJECT(periodic),
+				"margin", 6,
+				"color-style", GCU_PERIODIC_COLOR_DEFAULT,
+				"can_unselect", true,
+	            "expand", true,
+				NULL);
 	g_signal_connect(G_OBJECT(periodic), "element_changed", (GCallback)on_changed, this);
-	gtk_box_pack_end (GTK_BOX(vbox), GTK_WIDGET(GTK_PERIODIC(periodic)), true, true, 0);
-	gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(vbox));
+	gtk_container_add (GTK_CONTAINER (grid), GTK_WIDGET (periodic));
+	gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET (grid));
 	gtk_widget_show_all(window);
+	g_object_unref (ui_manager);
 	for (int i = 0; i < 118; i++)
 		Pages[i] = NULL;
-	
-	gcu::Element::LoadAllData ();
-	colorschemes["none"] = GTK_PERIODIC_COLOR_NONE;
-	colorschemes["default"] = GTK_PERIODIC_COLOR_DEFAULT;
 
-	UIBuilder *builder = new UIBuilder (UIDIR"/state-thermometer.ui", GETTEXT_PACKAGE);
+	gcu::Element::LoadAllData ();
+	gcu_periodic_set_tips (periodic, GCU_PERIODIC_TIP_STANDARD);
+	colorschemes["none"] = GCU_PERIODIC_COLOR_NONE;
+	colorschemes["default"] = GCU_PERIODIC_COLOR_DEFAULT;
+
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/state-thermometer.ui", GETTEXT_PACKAGE);
 	GtkWidget *thermometer = builder->GetRefdWidget ("state-thermometer");
-	colorschemes["state"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_state_color, thermometer, this);
+	colorschemes["state"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_state_color, thermometer, this);
 	gtk_widget_show_all (thermometer);
 	thermometer = builder->GetWidget ("temperature");
 	g_signal_connect (G_OBJECT (thermometer), "value-changed", G_CALLBACK (on_changed_temp), this);
 	temperature = gtk_range_get_value (GTK_RANGE (thermometer));
 	delete builder;
 
-	builder = new UIBuilder (UIDIR"/family.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/family.ui", GETTEXT_PACKAGE);
 	GtkWidget *familywidget = builder->GetRefdWidget ("family-legend");
-	colorschemes["family"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_family_color, familywidget, this);	
+	colorschemes["family"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_family_color, familywidget, this);
 	gtk_widget_show_all (familywidget);
 	familywidget = builder->GetWidget ("family-box");
 	gtk_combo_box_set_active (GTK_COMBO_BOX(familywidget), 0);
@@ -349,27 +358,31 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 	g_signal_connect (G_OBJECT (familywidget), "changed", G_CALLBACK (on_changed_family), this);
 	delete builder;
 
-	builder = new UIBuilder (UIDIR"/acidity.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/acidity.ui", GETTEXT_PACKAGE);
 	GtkWidget *aciditylegend = builder->GetRefdWidget ("acidity-legend");
-	colorschemes["acidity"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_acidity_color, aciditylegend, this);
+	colorschemes["acidity"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_acidity_color, aciditylegend, this);
 	gtk_widget_show_all (aciditylegend);
 	delete builder;
 
-	colorschemes["electroneg"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_electroneg_color, NULL, this);
+	colorschemes["electroneg"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_electroneg_color, NULL, this);
 
-	colorschemes["radius"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_radius_color, NULL, this);
+	colorschemes["radius"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_radius_color, NULL, this);
 
-	builder = new UIBuilder (UIDIR"/block.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/block.ui", GETTEXT_PACKAGE);
 	GtkWidget *blocklegend = builder->GetRefdWidget ("block-legend");
-	colorschemes["block"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_block_color, blocklegend, this);
+	colorschemes["block"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_block_color, blocklegend, this);
 	gtk_widget_show_all (blocklegend);
 	delete builder;
 	gct_data_init ();
 
 }
 
+extern GObject *Copied;
+
 GChemTableApp::~GChemTableApp ()
 {
+	if (Copied)
+		g_object_unref (Copied);
 	gct_data_clear ();
 }
 
@@ -378,7 +391,7 @@ void GChemTableApp::OnAbout ()
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemTable is a chemical periodic table of the elements application");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
+	const gchar * copyright = _("Copyright © 2005-2010 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -392,20 +405,18 @@ void GChemTableApp::OnAbout ()
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301\n"
 		"USA";
-	
-	gtk_about_dialog_set_url_hook (on_about_activate_url, this, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (GetWindow (),
-	                       "name", "GChemTable",
+	                       "program-name", "GChemTable",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
@@ -416,7 +427,7 @@ void GChemTableApp::OnElement (int Z)
 		return;
 	int t = Z - 1;
 	if (Pages[t] != NULL)
-		gtk_window_present (Pages[t]->GetWindow ());
+		Pages[t]->Present ();
 	else
 		Pages[t] = new GChemTableElt (this, Z);
 }
@@ -424,7 +435,7 @@ void GChemTableApp::OnElement (int Z)
 void GChemTableApp::ClearPage (int Z)
 {
 	Pages[Z - 1] = NULL;
-	gtk_periodic_set_element (periodic, 0);
+	gcu_periodic_set_element (periodic, 0);
 	if (Z == m_CurZ) {
 		SetCurZ (0);
 	}
@@ -433,7 +444,7 @@ void GChemTableApp::ClearPage (int Z)
 void GChemTableApp::SetCurZ (int Z)
 {
 	if (Z != m_CurZ) {
-		gtk_periodic_set_element (periodic, Z);
+		gcu_periodic_set_element (periodic, Z);
 		m_CurZ = Z;
 	}
 }
@@ -446,25 +457,25 @@ void GChemTableApp::SetColorScheme (char const *name)
 void GChemTableApp::SetTemperature (double T)
 {
 	temperature = T;
-	gtk_periodic_set_colors (periodic);
+	gcu_periodic_set_colors (periodic);
 }
 
 void GChemTableApp::SetFamily (int family_N)
 {
 	family = (family_N)? 1 << (family_N - 1): -1;
-	gtk_periodic_set_colors (periodic);
+	gcu_periodic_set_colors (periodic);
 }
 
-void GChemTableApp::GetStateColor (int Z, GdkColor *color)
+void GChemTableApp::GetStateColor (int Z, GdkRGBA *rgba)
 {
-	color->red= color->green = color->blue = 0;
+	rgba->red= rgba->green = rgba->blue = 0.;
 	Element *elt = Element::GetElement (Z);
 	Value const *value = elt->GetProperty ("meltingpoint");
 	if (!value)
 		return;
 	double t = value->GetAsDouble ();
 	if (t > temperature) {
-		color->blue = 0xffff;
+		rgba->blue = 1.;
 		return;
 	}
 	value = elt->GetProperty ("boilingpoint");
@@ -472,15 +483,15 @@ void GChemTableApp::GetStateColor (int Z, GdkColor *color)
 		return;
 	t = value->GetAsDouble ();
 	if (t > temperature) {
-		color->green = 0xffff;
+		rgba->green = 1.;
 		return;
 	}
-	color->red = 0xffff;
+	rgba->red = 1.;
 }
 
-void GChemTableApp::GetFamilyColor (int Z, GdkColor *color)
+void GChemTableApp::GetFamilyColor (int Z, GdkRGBA *rgba)
 {
-	color->red= color->green = color->blue = 0;
+	rgba->red= rgba->green = rgba->blue = 0;
         Element *elt = Element::GetElement (Z);
 	std::string &value = elt->GetStringProperty ("family");
 	if (!value.length())
@@ -497,71 +508,71 @@ void GChemTableApp::GetFamilyColor (int Z, GdkColor *color)
 	Noblegas
 	Rare_Earth
 */
-	
+
 	if (value == "Alkali_Earth") {
 		if (family & 1)
-			color->blue = 0x8eff;
+			rgba->blue = 0.558;
 		return;
 	}
 
 	if (value == "Alkaline_Earth") {
 		if (family & 2)
-			color->blue = 0xffff;
+			rgba->blue = 1.;
 		return;
 	}
 
 	if (value == "Non-Metal") {
 		if (family & 0x20)
-			color->green = 0xffff;
+			rgba->green = 1.;
 		return;
 	}
 
 	if (value == "Metalloids") {
 		if (family & 8)
-			color->green = 0x8eff;
+			rgba->green = 0.558;
 		return;
 	}
 
 	if (value == "Transition") {
 		if (family & 0x80) {
-			color->red = 0xffff;
-			color->green = 0xffff;
+			rgba->red = 1.;
+			rgba->green = 1.;
 		}
 		return;
 	}
 
 	if (value == "Other_Metal") {
 		if (family & 0x100) {
-			color->red = 0xffff;
-			color->green = 0x8eff;
+			rgba->red = 1.;
+			rgba->green = 0.558;
 		}
 		return;
 	}
 
 	if (value == "Halogene") {
 		if (family & 4)
-			color->red = 0xffff;
+			rgba->red = 1.;
 		return;
 	}
 
 	if (value == "Noblegas") {
 		if (family & 0x10)
-			color->red = 0x8eff; 
+			rgba->red = 0.558;
 		return;
 	}
 
 	if (value == "Rare_Earth") {
 		if (family & 0x40) {
-			color->red = 0xffff;
-			color->blue = 0xffff;
+			rgba->red = 1.;
+			rgba->blue = 1.;
 		}
 		return;
 	}
 }
 
-void GChemTableApp::GetAcidityColor (int Z, GdkColor *color)
+void GChemTableApp::GetAcidityColor (int Z, GdkRGBA *rgba)
 {
-	color->red= color->green = color->blue = 0;
+	rgba->red= rgba->green = rgba->blue = 0.;
 	Element *elt = Element::GetElement (Z);
 	int value = elt->GetIntegerProperty ("acidicbehaviour");
 	if (value == GCU_ERROR)
@@ -576,31 +587,31 @@ void GChemTableApp::GetAcidityColor (int Z, GdkColor *color)
 
 	switch (value) {
 	case 0:
-		color->red = 0xffff;
+		rgba->red = 1.;
 		return;
 
 	case 1:
-		color->blue = 0xffff;
+		rgba->blue = 1.;
 		return;
 
 	case 2:
-		color->green = 0xffff;
+		rgba->green = 1.;
 		return;
 
 	case 3:
-		color->red = 0xffff;
-		color->blue = 0xffff;
+		rgba->red = 1.;
+		rgba->blue =1.;
 		return;
 	}
 }
 
-void GChemTableApp::GetElectronegColor (int Z, GdkColor *color)
+void GChemTableApp::GetElectronegColor (int Z, GdkRGBA *rgba)
 {
 	double max=3.98;
 	double min=0.7;
 	double limit;
 
-	color->red= color->green = color->blue = 0;
+	rgba->red= rgba->green = rgba->blue = 0;
 	Element *elt = Element::GetElement (Z);
 	Value const *value = elt->GetProperty ("electronegativityPauling");
 	if (!value)
@@ -611,22 +622,22 @@ void GChemTableApp::GetElectronegColor (int Z, GdkColor *color)
 	limit = 0.5 * (max - min);
 
 	if (en < limit) {
-		color->red = 0xffff;
-		color->blue = static_cast<guint16> ((en - min) * 0xffff / (limit - min));
+		rgba->red = 1.;
+		rgba->blue = (en - min) / (limit - min);
 	} else {
-		color->blue = 0xffff;
-		color->red= static_cast<guint16> ((en - max) * 0xffff / (limit - max));
+		rgba->blue = 1.;
+		rgba->red= (en - max) / (limit - max);
 	}
 
 }
 
-void GChemTableApp::GetRadiusColor (int Z, GdkColor *color)
+void GChemTableApp::GetRadiusColor (int Z, GdkRGBA *rgba)
 {
 	double max=2.25;
 	double min=0.32;
 	double limit;
 
-	color->red = color->green = color->blue = 0;
+	rgba->red = rgba->green = rgba->blue = 0.;
 	Element *elt = Element::GetElement (Z);
 	Value const *value = elt->GetProperty ("radiusCovalent");
 	if (!value)
@@ -637,48 +648,52 @@ void GChemTableApp::GetRadiusColor (int Z, GdkColor *color)
 	limit = 0.5 * (max - min);
 
 	if (radius < limit) {
-		color->red = 0xffff;
-		color->blue = static_cast<guint16> ((radius - min) * 0xffff / (limit - min));
+		rgba->red = 1.;
+		rgba->blue = (radius - min) / (limit - min);
 	} else {
-		color->blue = 0xffff;
-		color->red= static_cast<guint16> ((radius - max) * 0xffff / (limit - max));
+		rgba->blue = 1.;
+		rgba->red= (radius - max) / (limit - max);
 	}
 
 }
 
-void GChemTableApp::GetBlockColor (int Z, GdkColor *color)
+void GChemTableApp::GetBlockColor (int Z, GdkRGBA *rgba)
 {
-	color->red= color->green = color->blue = 0;
+	rgba->red= rgba->green = rgba->blue = 0.;
         Element *elt = Element::GetElement (Z);
 	std::string &value = elt->GetStringProperty ("periodTableBlock");
 	if (!value.length())
 		return;
 
 	if (value == "s") {
-		color->blue = 0x8eff;
+		rgba->blue = 0.558;
 		return;
 	}
 
 	if (value == "p") {
-		color->red = 0x8eff;
+		rgba->red = 0.558;
 		return;
 	}
 
 	if (value == "d") {
-		color->green = 0x8eff;
+		rgba->green = 0.558;
 		return;
 	}
 
 	if (value == "f") {
-		color->blue = 0x8eff;
-		color->red = 0x8eff;
+		rgba->blue = 0.558;
+		rgba->red = 0.558;
 		return;
 	}
 }
 
 void GChemTableApp::OnNewChart (char const *name)
 {
-	new GChemTableCurve (this, name);
+	Dialog *dlg = (name)? GetDialog (name): NULL;
+	if (dlg)
+		dlg->Present ();
+	else
+		new GChemTableCurve (this, name);
 }
 
 void GChemTableApp::OnSaveAsImage (GChemTableCurve *curve)
@@ -698,7 +713,7 @@ void GChemTableApp::OnSaveAsImage (GChemTableCurve *curve)
 	l.push_front ("application/postscript");
 	l.push_front ("application/pdf");
 	l.push_front ("image/svg+xml");
-	FileChooser (this, true, l, reinterpret_cast <Document *> (curve), _("Save as image"), GetImageSizeWidget ());
+	gcugtk::FileChooser (this, true, l, reinterpret_cast <Document *> (curve), _("Save as image"), GetImageSizeWidget ());
 }
 
 bool GChemTableApp::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, Document *Doc)
